##  SAP Discovery Inbox
The SAP discover inbox displays systems, services, and custom-built applications found in your SAP landscape. You can use the inbox to review these items, link them to existing fact sheets, and create and link new fact sheets. If any of the discovered items aren’t relevant to you, you can always reject them.
For detailed information, refer to [SAP Discovery Inbox](https://help.sap.com/docs/leanix/ea/sap-landscape-discovery-inbox?locale=en-US&state=PRODUCTION&version=CLOUD "Discovered products, services, and extensions from your SAP landscape appear in the SAP discovery inbox. Learn how to create, link, and reject fact sheets related to discovered items.").
SAP Discovery Inbox with Discoveries
![The SAP Discovery Inbox interface showing discovered items, their status, and linked fact sheets.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioe1dfea10736f4a10bb8929f4c714a1d7_LowRes.png)
